@@ -316,14 +316,14 @@ fill_theme_button (Animation_WallpaperPrivate *priv, GtkWidget *button, gchar *c
     if (!strcmp(category, "Unknown")){
         store = priv->extheme_list;
         while (store){  
-            if (!strcmp("Sherman's Aquarium" , g_hash_table_lookup(store->data, "name"))){
+            if (!strcmp("Shermans Aquarium" , g_hash_table_lookup(store->data, "name"))){
                 flag = TRUE;
                 break;
             }
             store = g_slist_next(store);
         }
         if (!flag)
-            hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "Sherman's Aquarium");
+            hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "Shermans Aquarium");
     }
 
         hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (button),
@@ -659,7 +659,7 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
                     }
                 }
                 /* Check Xsnow program */
-                if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), "Sherman's Aquarium")){
+                if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), "Shermans Aquarium")){
                     if (access("/usr/bin/shermans", F_OK) != 0){
                         hildon_banner_show_information(GTK_WIDGET(button), NULL, 
                         _("You haven't got the installed package 'Sherman's Aquarium'. Please install it via using Application Manager"));
