@@ -39,7 +39,7 @@ void send_dbus_signal (Animation_WallpaperPrivate *priv, const gchar *interface,
                   const gchar *path, const gchar *member);
 gint read_config(Animation_WallpaperPrivate *priv);
 void lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv); 
-void theme_button_clicked(GtkButton *button, Animation_WallpaperPrivate *priv);
+void theme_button_clicked(GtkWidget *button, GdkEventButton *event, Animation_WallpaperPrivate *priv);
 void rich_animation_additional_parametr(GtkWidget *vbox, Animation_WallpaperPrivate *priv);
 void additional_parametr_for_theme_video(GtkWidget *vbox, Animation_WallpaperPrivate *priv);
 GSList * get_list_exthemes(void);
